| Title: | Targeted Learning for Causal Mediation Analysis |
|---|---|
| Description: | Targeted maximum likelihood (TML) estimation of population-level causal effects in mediation analysis. The causal effects are defined by joint static or stochastic interventions applied to the exposure and the mediator. Targeted doubly robust estimators are provided for the classical natural direct and indirect effects, as well as the more recently developed population intervention direct and indirect effects. |
| Authors: | Nima Hejazi [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-7127-2789>), James Duncan [aut], David McCoy [aut], Mark van der Laan [ctb, ths] (ORCID: <https://orcid.org/0000-0003-1432-5511>) |
| Maintainer: | Nima Hejazi <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.3 |
| Built: | 2026-05-25 09:57:31 UTC |
| Source: | https://github.com/tlverse/tmle3mediate |
Likelihood Factor for Incremental Propensity Score Interventions
R6Class object.
LF_base object.
define_lf(LF_ipsi, name, type = "density", likelihood_base,
shift_param, treatment_task, control_task, ...)
nameA character, giving the name of the likelihood
factor. Should match a node name in the nodes specified by the
npsem slot of tmle3_Task.
likelihood_baseA trained Likelihood
object, for use in generating a re-scaled likelihood factor.
shift_paramA numeric, specifying the magnitude of
the desired incremental propensity score shift (a multiplier of
the odds of receiving treatment).
treatment_taskA tmle3_Task object
created by setting the intervention to the treatment condition:
do(A = 1).
control_taskA tmle3_Task object
created by setting the intervention to the control condition:
do(A = 0).
...Not currently used.
likelihood_baseA trained Likelihood
object, for use in generating a re-scaled likelihood factor.
shift_paramA numeric, specifying the magnitude of
the desired incremental propensity score shift (a multiplier of
the odds of receiving treatment).
treatment_taskA tmle3_Task object
created by setting the intervention to the treatment condition:
do(A = 1).
control_taskA tmle3_Task object
created by setting the intervention to the control condition:
do(A = 0).
...Additional arguments passed to the base class.
Kennedy, Edward H (2019). Journal of the American Statistical Association. https://doi.org/10.1080/01621459.2017.1422737
Díaz, Iván and Hejazi, Nima S (2020). Journal of the Royal Statistical Society, Series B. https://doi.org/10.1111/rssb.12362
Parameter definition class. See https://doi.org/10.1111/rssb.12362.
R6Class object.
Param_base object.
define_param(Param_medshift, shift_param, ..., outcome_node)
observed_likelihoodA Likelihood
corresponding to the observed likelihood.
shift_paramA numeric, specifying the magnitude of
the desired incremental propensity score shift (a multiplier of
the odds of receiving treatment).
...Not currently used.
outcome_nodeA character, giving the name of the
node that should be treated as the outcome.
cf_likelihoodThe counterfactual likelihood under the joint stochastic intervention on exposure and mediators.
lf_ipsiObject derived from LF_base
for assessing the joint intervention on exposure and mediators.
treatment_taskA tmle3_Task created
by setting the intervention to the treatment condition:
do(A = 1).
control_taskA tmle3_Task object created by
setting the intervention to the control condition: do(A = 0).
shift_paramA numeric, specifying the magnitude of
the desired incremental propensity score shift (a multiplier of
the odds of receiving treatment).
Other Parameters:
Param_NDE,
Param_NIE
Parameter definition class. See https://www.ncbi.nlm.nih.gov/pubmed/22499725
R6Class object.
Param_base object
define_param(Param_NDE, observed_likelihood, ...,
outcome_node)
observed_likelihoodA Likelihood
corresponding to the observed likelihood.
...Not currently used.
outcome_nodeA character, giving the name of the
node that should be treated as the outcome.
cf_likelihood_treatmentThe counterfactual likelihood for the treatment.
cf_likelihood_controlThe counterfactual likelihood for the control.
treatment_tasktmle3_Task created by
setting the intervention to the treatment condition: do(A = 1).
control_tasktmle3_Task created by
setting the intervention to the control condition: do(A = 0).
Other Parameters:
Param_NIE,
Param_medshift
Parameter definition class. See https://www.ncbi.nlm.nih.gov/pubmed/22499725
R6Class object.
Param_base object
define_param(Param_NIE, observed_likelihood, ...,
outcome_node)
observed_likelihoodA Likelihood
corresponding to the observed likelihood.
...Not currently used.
outcome_nodeA character, giving the name of the
node that should be treated as the outcome.
cf_likelihood_treatmentThe counterfactual likelihood for the treatment.
cf_likelihood_controlThe counterfactual likelihood for the control.
treatment_tasktmle3_Task created by
setting the intervention to the treatment condition: do(A = 1).
control_tasktmle3_Task created by
setting the intervention to the control condition: do(A = 0).
Other Parameters:
Param_NDE,
Param_medshift
O = (W, A, Z, Y) W = Covariates (possibly multivariate) A = Treatment (binary or categorical) Z = Mediators (binary or categorical; possibly multivariate) Y = Outcome (binary or bounded continuous)
tmle_medshift( shift_type = "ipsi", delta, e_learners, phi_learners, max_iter = 10000, step_size = 1e-06, ... )tmle_medshift( shift_type = "ipsi", delta, e_learners, phi_learners, max_iter = 10000, step_size = 1e-06, ... )
shift_type |
A |
delta |
A |
e_learners |
A |
phi_learners |
A |
max_iter |
A |
step_size |
A |
... |
Additional arguments (currently unused). |
O = (W, A, Z, Y) W = Covariates (possibly multivariate) A = Treatment (binary or categorical) Z = Mediators (binary or categorical; possibly multivariate) Y = Outcome (binary or bounded continuous)
tmle_NDE(e_learners, psi_Z_learners, max_iter = 10000, step_size = 1e-06, ...)tmle_NDE(e_learners, psi_Z_learners, max_iter = 10000, step_size = 1e-06, ...)
e_learners |
A |
psi_Z_learners |
A |
max_iter |
A |
step_size |
A |
... |
Additional arguments (currently unused). |
O = (W, A, Z, Y) W = Covariates (possibly multivariate) A = Treatment (binary or categorical) Z = Mediators (binary or categorical; possibly multivariate) Y = Outcome (binary or bounded continuous)
tmle_NIE(e_learners, psi_Z_learners, max_iter = 10000, step_size = 1e-06, ...)tmle_NIE(e_learners, psi_Z_learners, max_iter = 10000, step_size = 1e-06, ...)
e_learners |
A |
psi_Z_learners |
A |
max_iter |
A |
step_size |
A |
... |
Additional arguments (currently unused). |
TML Estimator for the Population Intervention (In)direct Effects
TML Estimator for the Natural Indirect Effect